import{d as a,e as n,f as c,o as i,c as r,a as o,j as s,t as _,h as d}from"./index-lMNTh-nA.js";const l={style:{"background-color":"#d2d2fa",height:"100vh",display:"grid","place-items":"center"}},p={style:{"text-align":"center"}},h=o("a",{href:"https://github.com/xaoyaoo/PyWxDump.git"},"PyWxDump",-1),g={style:{"text-align":"center"}},f=a({__name:"HomeView",setup(m){const t=n("");return c(async()=>{try{const e=await d.get("/api/version");t.value=e}catch(e){t.value="获取版本失败",console.log(e)}}),(e,y)=>(i(),r("div",l,[o("h2",p,[s("欢迎使用"),h,s("聊天记录查看工具! "),o("p",g,"当前版本："+_(t.value),1)])]))}});export{f as _};
